import * as C from './convert.js';
import { Bytes, Data, Json } from './types.js';
type BufferLike = bigint | boolean | number | string | Uint8Array;
export declare const Hex: {
    encode: (x: Uint8Array) => string;
    decode: (x: string) => Uint8Array;
    normalize: (x: Bytes) => Uint8Array;
};
export declare const Txt: {
    encode: (x: Uint8Array) => string;
    decode: (x: string) => Uint8Array;
    serialzie: (x: Data) => Uint8Array;
    revitalize: (x: Data) => Json;
};
export declare const Base64: {
    encode: (x: Uint8Array) => string;
    decode: (x: string) => Uint8Array;
    encodeUrl: (x: Uint8Array) => string;
    decodeUrl: (x: string) => Uint8Array;
};
export declare class Buff extends Uint8Array {
    static num: (number: number, size?: number, endian?: 'le' | 'be') => Buff;
    static big: (number: bigint, size?: number, endian?: 'le' | 'be') => Buff;
    static b58check(data: string): Promise<Buff>;
    static any: (data: BufferLike, size?: number) => Buff;
    static raw: (data: ArrayBufferLike, size?: number) => Buff;
    static str: (data: string, size?: number) => Buff;
    static hex: (data: string, size?: number) => Buff;
    static json: (data: Json) => Buff;
    static base64: (data: string) => Buff;
    static b64url: (data: string) => Buff;
    static bech32: (data: string, ver?: number) => Buff;
    constructor(data: ArrayBufferLike, size?: number);
    get num(): number;
    get big(): bigint;
    get arr(): number[];
    get str(): string;
    get hex(): string;
    get raw(): Uint8Array;
    get base64(): string;
    get b64url(): string;
    get digest(): Promise<Uint8Array>;
    get id(): Promise<string>;
    toNum(endian?: 'le' | 'be'): number;
    toBig(endian?: 'le' | 'be'): bigint;
    toDigest(type?: AlgorithmIdentifier): Promise<Uint8Array>;
    tob58check(): Promise<string>;
    toArr(): number[];
    toStr(): string;
    toHex(): string;
    toJson(): Json;
    toBytes(): Uint8Array;
    toB64url(): string;
    toBase64(padding?: boolean): string;
    toBech32(hrp: string, ver?: number): string;
    prepend(data: Uint8Array): Buff;
    append(data: Uint8Array): Buff;
    slice(start?: number, end?: number): Buff;
    rev: () => Buff;
    reverse(): Buff;
    write(bytes: Uint8Array, offset?: number): void;
    prefixSize(num?: number): Buff;
    static from(data: Uint8Array | number[]): Buff;
    static of(...args: number[]): Buff;
    static join(arr: Uint8Array[]): Buff;
    static readSize(num: number): Buff;
    static random(size?: number): Buff;
    static encode: typeof C.strToBytes;
    static decode: typeof C.bytesToStr;
    static normalize(data: Bytes, size?: number): Uint8Array;
    static serialize(data: Data): Uint8Array;
    static revitalize(data: Data): Json;
}
export {};
//# sourceMappingURL=buff.d.ts.map